@@ -14,6 +14,6 @@ enum SimpleEnum {
 fn test_simple_enum() {
     assert_eq!(
         SimpleEnum::decl(),
-        r#"export type SimpleEnum = "asdf" | "B" | "C";"#
+        r#"type SimpleEnum = "asdf" | "B" | "C";"#
     )
 }
