@@ -16,6 +16,6 @@ enum RenamedEnum {
 fn test_simple_enum() {
     assert_eq!(
         RenamedEnum::decl(),
-        r#"export type SimpleEnum = "ASDF" | "b" | "c";"#
+        r#"type SimpleEnum = "ASDF" | "b" | "c";"#
     )
 }
