@@ -24,17 +24,9 @@ enum SimpleEnum {
 
 #[test]
 fn test_stateful_enum() {
-    assert_eq!(
-        Foo::decl(),
-        r#"interface Foo {
-    bar: Bar,
-}"#
-    );
+    assert_eq!(Foo::decl(), r#"interface Foo { bar: Bar, }"#);
     assert_eq!(
         SimpleEnum::decl(),
-        r#"type SimpleEnum = string | number | "C" | [string, number] | Foo | {
-    a: number,
-    b: string,
-};"#
+        r#"type SimpleEnum = string | number | "C" | [string, number] | Foo | { a: number, b: string, };"#
     );
 }
